==> molecule-1.19.1.tar.gz: molecule-1.19.1/test/unit/command/test_dependency.py <==
#  Copyright (c) 2015-2016 Cisco Systems, Inc.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to
#  deal in the Software without restriction, including without limitation the
#  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
#  sell copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.

from molecule.command import dependency


def test_execute(patched_ansible_galaxy, patched_print_info,
                 molecule_instance):
    molecule_instance.config.config['dependency']['requirements_file'] = True

    d = dependency.Dependency({}, {}, molecule_instance)
    d.execute()

    msg = "Downloading dependencies with 'galaxy'..."
    patched_print_info.assert_called_once_with(msg)

    patched_ansible_galaxy.assert_called_once()
    assert molecule_instance.state.installed_deps


def test_execute_does_not_install_when_installed(patched_ansible_galaxy,
                                                 molecule_instance):
    molecule_instance.config.config['dependency']['requirements_file'] = True
    molecule_instance.state.change_state('installed_deps', True)

    d = dependency.Dependency({}, {}, molecule_instance)
    d.execute()

    assert not patched_ansible_galaxy.called


def test_execute_shell(patched_shell, patched_print_info, molecule_instance):
    molecule_instance.dependency = 'shell'
    molecule_instance.config.config['dependency']['command'] = True

    d = dependency.Dependency({}, {}, molecule_instance)
    d.execute()

    msg = "Downloading dependencies with 'shell'..."
    patched_print_info.assert_called_once_with(msg)

    patched_shell.assert_called_once_with()
    assert molecule_instance.state.installed_deps


def test_execute_shell_does_not_install_when_installed(patched_shell,
                                                       molecule_instance):
    molecule_instance.dependency = 'shell'
    molecule_instance.config.config['dependency']['command'] = True
    molecule_instance.state.change_state('installed_deps', True)

    d = dependency.Dependency({}, {}, molecule_instance)
    d.execute()

    assert not patched_shell.called

==> molecule-2.10.1.tar.gz: molecule-2.10.1/test/unit/command/test_dependency.py <==
#  Copyright (c) 2015-2017 Cisco Systems, Inc.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to
#  deal in the Software without restriction, including without limitation the
#  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
#  sell copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.

from molecule.command import dependency


def test_execute(mocker, patched_logger_info, patched_ansible_galaxy,
                 config_instance):
    d = dependency.Dependency(config_instance)
    d.execute()

    x = [
        mocker.call("Scenario: 'default'"),
        mocker.call("Action: 'dependency'"),
    ]
    assert x == patched_logger_info.mock_calls

    patched_ansible_galaxy.assert_called_once_with()
